local tablet = AceLibrary("Tablet-2.0")
local L = AceLibrary("AceLocale-2.2"):new("FuBar_LootTypeFu")
local Dewdrop = AceLibrary("Dewdrop-2.0")

LootTypeFu = AceLibrary("AceAddon-2.0"):new("AceEvent-2.0", "AceConsole-2.0", "AceDB-2.0", "FuBarPlugin-2.0")

LootTypeFu:RegisterDB("LootTypeFuDB")
LootTypeFu:RegisterDefaults('profile', 
	{
	}
)

LootTypeFu.version = "1.0." .. string.sub("$Revision: 9785 $", 12, -3)
LootTypeFu.date = string.sub("$Date: 2006-09-02 10:55:39 +0930 (Sat, 02 Sep 2006) $", 8, 17)
LootTypeFu.hasIcon = "Interface\\AddOns\\FuBar_LootTypeFu\\LootType.tga"
LootTypeFu.defaultPosition = 'LEFT'
LootTypeFu.hideWithoutStandby = true
LootTypeFu.independentProfile = true
LootTypeFu.clickableTooltip = true

LootTypeFu.OnMenuRequest = 
{
	handler = LootTypeFu,
	type = 'group',
	args = 
	{
	},
}


function LootTypeFu:OnInitialize()
end

function LootTypeFu:OnEnable()
    self:RegisterEvent("PARTY_MEMBERS_CHANGED", "UpdateDisplay")
    self:RegisterEvent("RAID_ROSTER_UPDATE", "UpdateDisplay")
    self:RegisterEvent("PARTY_LOOT_METHOD_CHANGED", "UpdateDisplay")
end

function LootTypeFu:OnDisable()
end

function LootTypeFu:OnTextUpdate()
	if (GetNumPartyMembers() > 0) or (GetNumRaidMembers() > 0) then
		local lootTypeText = L[GetLootMethod()]
		local color = ITEM_QUALITY_COLORS[GetLootThreshold()].hex

		self:SetText(color..lootTypeText)
	else
		self:SetText(L["Inactive"])
	end
end

local lootTypeList =
{
	freeforall		= true,
	roundrobin		= true,
	master			= true,
	group			= true,
	needbeforegreed = true,
}

function LootTypeFu:CanChangeLootType()
	return (GetNumPartyMembers() + GetNumRaidMembers() > 0) and IsPartyLeader()
end

local temporaryTable = { }
local unknownColor = { 0.5, 0.5, 0.5 }

function LootTypeFu:OnTooltipUpdate()
	if (GetNumPartyMembers() > 0) or (GetNumRaidMembers() > 0) then

		local canChangeLoot = self:CanChangeLootType()
		local lootMethod = GetLootMethod()
		
		tablet:SetTitle(L["Loot Type"])
		local cat = tablet:AddCategory('text',L["Loot Mode"])
		for k in pairs(lootTypeList) do
			cat:AddLine(
				'text', L[k],
				'textR', not canChangeLoot and 0.6 or nil,
				'textG', not canChangeLoot and 0.6 or nil,
				'textB', not canChangeLoot and 0.6 or nil,
				'hasCheck', true,
				'checked', k == lootMethod,
				'func', canChangeLoot and 'OnClickLootType' or nil,
				'arg1', self,
				'arg2', k
			)
		end
		
		if lootMethod ~= "freeforall" then
			-- Show threshold options
			local cat = tablet:AddCategory('text',L["Loot Threshold"])
			
			for i = 0, 6 do
				cat:AddLine(
					'text', _G["ITEM_QUALITY"..i.."_DESC"],
					'textR', ITEM_QUALITY_COLORS[i].r,
					'textG', ITEM_QUALITY_COLORS[i].g,
					'textB', ITEM_QUALITY_COLORS[i].b,
					'hasCheck', true,
					'checked', i == GetLootThreshold(),
					'func', canChangeLoot and 'OnClickLootThreshold' or nil,
					'arg1', self,
					'arg2', i
				)			
			end
		end
		
		if lootMethod == "master" then
			local cat = tablet:AddCategory('text', L["Master Looter"])
			local masterLooter

			if GetNumRaidMembers() == 0 then
				_, masterLooter = GetLootMethod()
				if masterLooter then
					if masterLooter == 0 then
						masterLooter = "player"
					else
						masterLooter = "party"..masterLooter
					end
				end

				table.insert(temporaryTable, "player")
				for i = 1,GetNumPartyMembers() do
					table.insert(temporaryTable, "party"..i)
				end
				
			else
				for i=1,GetNumRaidMembers() do
					local unitid = "raid"..i
					table.insert(temporaryTable, unitid)
					
					-- IsMasterLooter check
					if select(11, GetRaidRosterInfo(i)) then masterLooter = unitid end
				end
			end

			table.sort(temporaryTable, function(a, b) return UnitName(a) < UnitName(b) end)

			for i,k in ipairs(temporaryTable) do
				local _, class = UnitClass(k)
				local color = RAID_CLASS_COLORS[class] or unknownColor
			
				cat:AddLine(
					'text', UnitName(k),
					'textR', color.r,
					'textG', color.g,
					'textB', color.b,
					'hasCheck', true,
					'checked', k == masterLooter,
					'func', canChangeLoot and 'OnClickMasterLooter' or nil,
					'arg1', self,
					'arg2', UnitName(k)
				)
				
				temporaryTable[i] = nil
			end
		end

		tablet:SetHint(L["TOOLTIP_HINT"])
	end
end

function LootTypeFu:OnClickLootType(lootType)
	SetLootMethod(lootType, UnitName("player"))
end

function LootTypeFu:OnClickLootThreshold(threshold)
	SetLootThreshold(threshold)
end

function LootTypeFu:OnClickMasterLooter(name)
	SetLootMethod("master", name)
end
